package com.zbf.system.service.impl;

import java.util.List;
import com.zbf.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl; //添加
import com.zbf.system.mapper.SysUserBusinessColumnMapper;
import com.zbf.system.domain.SysUserBusinessColumn;
import com.zbf.system.service.ISysUserBusinessColumnService;

/**
 * 用户展示字段定义管理Service业务层处理
 *
 * @author tony
 * @date 2024-06-16
 */
@Service
public class SysUserBusinessColumnServiceImpl extends ServiceImpl<SysUserBusinessColumnMapper, SysUserBusinessColumn> implements ISysUserBusinessColumnService //修改
{
    @Autowired
    private SysUserBusinessColumnMapper sysUserBusinessColumnMapper;

    /**
     * 查询用户展示字段定义管理
     *
     * @param ID 用户展示字段定义管理主键
     * @return 用户展示字段定义管理
     */
    @Override
    public SysUserBusinessColumn selectSysUserBusinessColumnByID(Long ID)
    {
        return sysUserBusinessColumnMapper.selectSysUserBusinessColumnByID(ID);
    }

    /**
     * 查询用户展示字段定义管理列表
     *
     * @param sysUserBusinessColumn 用户展示字段定义管理
     * @return 用户展示字段定义管理
     */
    @Override
    public List<SysUserBusinessColumn> selectSysUserBusinessColumnList(SysUserBusinessColumn sysUserBusinessColumn)
    {
        return sysUserBusinessColumnMapper.selectSysUserBusinessColumnList(sysUserBusinessColumn);
    }

    /**
     * 新增用户展示字段定义管理
     *
     * @param sysUserBusinessColumn 用户展示字段定义管理
     * @return 结果
     */
    @Override
    public int insertSysUserBusinessColumn(SysUserBusinessColumn sysUserBusinessColumn)
    {
        sysUserBusinessColumn.setCreateTime(DateUtils.getNowDate());
        return sysUserBusinessColumnMapper.insertSysUserBusinessColumn(sysUserBusinessColumn);
    }

    /**
     * 修改用户展示字段定义管理
     *
     * @param sysUserBusinessColumn 用户展示字段定义管理
     * @return 结果
     */
    @Override
    public int updateSysUserBusinessColumn(SysUserBusinessColumn sysUserBusinessColumn)
    {
                sysUserBusinessColumn.setUpdateTime(DateUtils.getNowDate());
        return sysUserBusinessColumnMapper.updateSysUserBusinessColumn(sysUserBusinessColumn);
    }

    /**
     * 批量删除用户展示字段定义管理
     *
     * @param IDs 需要删除的用户展示字段定义管理主键
     * @return 结果
     */
    @Override
    public int deleteSysUserBusinessColumnByIDs(Long[] IDs)
    {
        return sysUserBusinessColumnMapper.deleteSysUserBusinessColumnByIDs(IDs);
    }

    /**
     * 删除用户展示字段定义管理信息
     *
     * @param ID 用户展示字段定义管理主键
     * @return 结果
     */
    @Override
    public int deleteSysUserBusinessColumnByID(Long ID)
    {
        return sysUserBusinessColumnMapper.deleteSysUserBusinessColumnByID(ID);
    }


    /**
     * 批量禁用
     *
     * @param ID 用户展示字段定义管理主键
     * @return 结果
     */
    @Override
    public int disabledSysUserBusinessColumnByIDs(Long[] IDs) {
        return sysUserBusinessColumnMapper.disabledSysUserBusinessColumnByIDs(IDs);
    }

    /**
     * 批量启用
     *
     * @param ID 用户展示字段定义管理主键
     * @return 结果
     */
    @Override
    public int enableSysUserBusinessColumnByIDs(Long[] IDs) {
        return sysUserBusinessColumnMapper.enableSysUserBusinessColumnByIDs(IDs);
    }

    /**
     * 修改状态
     *
     * @param sysUserBusinessColumn 工序管理主键
     * @return 结果
     */
    @Override
    public int updateStatus(SysUserBusinessColumn sysUserBusinessColumn) {
        return sysUserBusinessColumnMapper.updateSysUserBusinessColumn(sysUserBusinessColumn);
    }

}
